==> swc-1.3.97.tar.gz: swc-1.3.97/crates/swc_ecma_transforms_compat/tests/__swc_snapshots__/tests/es2022_class_properties.rs/regression_7371.js <==
"use strict";
class C {
}
class A extends C {
    constructor(){
        super();
        _define_property(this, "field", 1);
        class B extends C {
            constructor(){
                super();
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new A();
class Obj {
    constructor(){
        return {};
    }
}
// ensure superClass is still transformed
class SuperClass extends Obj {
    constructor(){
        var _temp;
        class B extends (_temp = super(), _define_property(this, "field", 1), _temp, Obj) {
            constructor(){
                super();
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new SuperClass();
// ensure ComputedKey Method is still transformed
class ComputedMethod extends Obj {
    constructor(){
        var _temp;
        let _tmp = (_temp = super(), _define_property(this, "field", 1), _temp);
        class B extends Obj {
            [_tmp]() {}
            constructor(){
                super();
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new ComputedMethod();
// ensure ComputedKey Field is still transformed
class ComputedField extends Obj {
    constructor(){
        var _temp;
        let _ref = (_temp = super(), _define_property(this, "field", 1), _temp);
        class B extends Obj {
            constructor(){
                super();
                _define_property(this, _ref, 1);
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new ComputedField();

==> swc-1.11.22.tar.gz: swc-1.11.22/crates/swc_ecma_transforms_compat/tests/__swc_snapshots__/tests/es2022_class_properties.rs/regression_7371.js <==
"use strict";
class C {
}
class A extends C {
    constructor(){
        super(), _define_property(this, "field", 1);
        class B extends C {
            constructor(){
                super();
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new A();
class Obj {
    constructor(){
        return {};
    }
}
// ensure superClass is still transformed
class SuperClass extends Obj {
    constructor(){
        class B extends (super(), _define_property(this, "field", 1), Obj) {
            constructor(){
                super();
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new SuperClass();
// ensure ComputedKey Method is still transformed
class ComputedMethod extends Obj {
    constructor(){
        let _tmp = [
            super(),
            _define_property(this, "field", 1)
        ][0];
        class B extends Obj {
            [_tmp]() {}
            constructor(){
                super();
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new ComputedMethod();
// ensure ComputedKey Field is still transformed
class ComputedField extends Obj {
    constructor(){
        let _ref = [
            super(),
            _define_property(this, "field", 1)
        ][0];
        class B extends Obj {
            constructor(){
                super(), _define_property(this, _ref, 1);
                expect(this.field).toBeUndefined();
            }
        }
        expect(this.field).toBe(1);
        new B();
    }
}
new ComputedField();
